@@ -1,15 +1,12 @@
 # Copyright 2022 DEViantUa <t.me/deviant_ua>
 # All rights reserved.
 from enkanetwork import EnkaNetworkAPI,Assets
-import logging,asyncio,random, os, datetime,time, sys
+import logging,asyncio,random, os, datetime,time
 from threading import Thread
 from .src.utils.CreatBannerTwo import generationTwo, creatUserInfo
 from .src.utils.CreatBannerOne import generationOne, signature, openUserImg 
-from .src.utils.translate import translate,supportLang
+from .src.utils.translation import translationLang,supportLang
 from .enc_error import ENCardError
-
-if sys.version_info[0] == 3 and sys.version_info[1] >= 6 and sys.platform.startswith('win'):
-    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
     
 logging.getLogger('enkanetwork.assets').setLevel(logging.CRITICAL)
 
@@ -46,11 +43,11 @@ def saveBanner(uid,res,name):
         pass
     res.save(f"{path}/EnkaImg/{uid}/{name}_{data}.png")
 
-def generation(charter,assets,img,adapt,uid,RESULT, save,signatureRes,translateLang,teample = 1):
+def generation(charter,assets,img,adapt,uid,RESULT, save,signatureRes,translateLang,splash,teample = 1):
     if teample == 1:
-        result = generationOne(charter,assets,img,adapt,signatureRes,translateLang["lvl"])
+        result = generationOne(charter,assets,img,adapt,signatureRes,translateLang["lvl"],splash)
     else:
-        result = generationTwo(charter,assets,img,adapt,signatureRes,translateLang)
+        result = generationTwo(charter,assets,img,adapt,signatureRes,translateLang,splash)
     if not save:
         saveBanner(uid,result,charter.name)
     else:
@@ -61,15 +58,19 @@ def generation(charter,assets,img,adapt,uid,RESULT, save,signatureRes,translateL
     return None
 
 class EnkaGenshinGeneration:
+
+    FIX_ASYNCIO_WIN = False
+
     def __init__(self,lang = "ru",charterImg = None,
             img = None, name = None, adapt = False,
-            randomImg = False, hide = False, dowload = False, namecard = False):
+            randomImg = False, hide = False, dowload = False, namecard = False, splash = False):
         if not lang in supportLang:
             raise ENCardError(6,"Dislike language List of available languages: en, ru, vi, th, pt, kr, jp, zh, id, fr, es, de, chs, cht.\nRead more in the documentation: https://github.com/DEViantUA/EnkaNetworkCard")
         self.assets = Assets(lang=lang)
         self.lang = lang
+        self.splash = splash
         self.namecard = namecard
-        self.translateLang = translate(lang = self.lang)
+        self.translateLang = translationLang[self.lang]
         self.adapt = adapt
         self.dowload = dowload
         self.hide = hide
@@ -106,6 +107,9 @@ class EnkaGenshinGeneration:
                 self.img = openUserImg(img)
     
     def start(self,uids, template = 1):
+
+        if self.FIX_ASYNCIO_WIN:
+            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         startPotoki = {}
         ResultEnka = {}
         if template < 1 or template > 2:
@@ -140,9 +144,9 @@ class EnkaGenshinGeneration:
     def startNameGeneration(self,key,uid,startPotoki,ResultEnka,signatureRes, teample):
         if not f"{uid}_{key.name.lower()}" in startPotoki:
             if self.randomImg:
-                startPotoki[f"{uid}_{key.name.lower()}"] = Thread(target=generation,args=(key,self.assets,openUserImg(random.choice(self.img)),self.adapt,uid,ResultEnka,self.dowload,signatureRes,self.translateLang, teample))
+                startPotoki[f"{uid}_{key.name.lower()}"] = Thread(target=generation,args=(key,self.assets,openUserImg(random.choice(self.img)),self.adapt,uid,ResultEnka,self.dowload,signatureRes,self.translateLang,self.splash, teample))
             else:
-                startPotoki[f"{uid}_{key.name.lower()}"] = Thread(target=generation,args=(key,self.assets,self.img,self.adapt,uid,ResultEnka,self.dowload,signatureRes,self.translateLang, teample))
+                startPotoki[f"{uid}_{key.name.lower()}"] = Thread(target=generation,args=(key,self.assets,self.img,self.adapt,uid,ResultEnka,self.dowload,signatureRes,self.translateLang,self.splash, teample))
             startPotoki[f"{uid}_{key.name.lower()}"].start()    
 
     def dowloadImg(self,startPotoki,ResultEnka):
